@@ -22,13 +22,12 @@
 
 #include <QApplication>
 #include <QClipboard>
-#include <QDebug>
 #include <QIcon>
 #include <QMimeData>
 #include <QMenu>
 #include <QQuickItem>
-#include <QQuickWindow>
 #include <QTimer>
+#include <QQuickWindow>
 
 #include <KFileItemActions>
 #include <KFileItemListProperties>
@@ -134,13 +133,17 @@ void Thumbnailer::showContextMenu(int x, int y, const QString &path, QQuickItem
     });
 
     if (KProtocolManager::supportsListing(url)) {
-        QAction *openContainingFolderAction = menu->addAction(QIcon::fromTheme("folder-open"), i18n("Open Containing Folder"));
+        QAction *openContainingFolderAction = menu->addAction(QIcon::fromTheme(QStringLiteral("folder-open")), i18n("Open Containing Folder"));
         connect(openContainingFolderAction, &QAction::triggered, [url] {
             KIO::highlightInFileManager({url});
         });
     }
 
-    menu->addSeparator();
+    KFileItemActions *actions = new KFileItemActions(menu);
+    KFileItemListProperties itemProperties(KFileItemList({fileItem}));
+    actions->setItemListProperties(itemProperties);
+
+    actions->addOpenWithActionsTo(menu);
 
     // KStandardAction? But then the Ctrl+C shortcut makes no sense in this context
     QAction *copyAction = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("&Copy"));
@@ -151,15 +154,10 @@ void Thumbnailer::showContextMenu(int x, int y, const QString &path, QQuickItem
         QApplication::clipboard()->setMimeData(data);
     });
 
-    KFileItemActions *actions = new KFileItemActions(menu);
-    KFileItemListProperties itemProperties(KFileItemList({fileItem}));
-    actions->setItemListProperties(itemProperties);
-
-    actions->addOpenWithActionsTo(menu);
     actions->addServiceActionsTo(menu);
     actions->addPluginActionsTo(menu);
 
-    QAction *propertiesAction = menu->addAction(QIcon::fromTheme("document-properties"), i18n("Properties"));
+    QAction *propertiesAction = menu->addAction(QIcon::fromTheme(QStringLiteral("document-properties")), i18n("Properties"));
     connect(propertiesAction, &QAction::triggered, [fileItem] {
         KPropertiesDialog *dialog = new KPropertiesDialog(fileItem.url());
         dialog->setAttribute(Qt::WA_DeleteOnClose);
