@@ -323,7 +323,7 @@ void UKMETIon::getXMLData(const QString& source)
 void UKMETIon::findPlace(const QString& place, const QString& source)
 {
     /* There's a page= parameter, results are limited to 10 by page */
-    const QUrl url(QLatin1String("http://www.bbc.com/locator/default/en-GB/search.json?search=")+place+
+    const QUrl url(QLatin1String("https://www.bbc.com/locator/default/en-GB/search.json?search=")+place+
                    QLatin1String("&filter=international&postcode_unit=false&postcode_district=true"));
 
     KIO::TransferJob* getJob = KIO::get(url, KIO::Reload, KIO::HideProgressInfo);
@@ -584,6 +584,8 @@ void UKMETIon::parseWeatherForecast(const QString& source, QXmlStreamReader& xml
 
 void UKMETIon::parseWeatherObservation(const QString& source, WeatherData& data, QXmlStreamReader& xml)
 {
+    Q_UNUSED(source);
+
     Q_ASSERT(xml.isStartElement() && xml.name() == QLatin1String("item"));
 
     while (!xml.atEnd()) {
@@ -747,8 +749,7 @@ bool UKMETIon::readObservationXMLData(const QString& source, QXmlStreamReader& x
             (data.observationDateTime.isValid() &&
             (!qIsNaN(data.stationLatitude) && !qIsNaN(data.stationLongitude)));
         if (canCalculateElevation) {
-            data.solarDataTimeEngineSourceName = QStringLiteral("%1|Solar|Latitude=%2|Longitude=%3|DateTime=%4")
-                .arg(QString::fromUtf8(data.observationDateTime.timeZone().id()))
+            data.solarDataTimeEngineSourceName = QStringLiteral("Local|Solar|Latitude=%1|Longitude=%2|DateTime=%3")
                 .arg(data.stationLatitude)
                 .arg(data.stationLongitude)
                 .arg(data.observationDateTime.toString(Qt::ISODate));
@@ -847,11 +848,7 @@ void UKMETIon::parseFiveDayForecast(const QString& source, QXmlStreamReader& xml
 
             const QString summaryLC = summary.toLower();
             forecast->period = period;
-            if (forecast->period == QLatin1String("Tonight")) {
-                forecast->iconName = getWeatherIcon(nightIcons(), summaryLC);
-            } else {
-                forecast->iconName = getWeatherIcon(dayIcons(), summaryLC);
-            }
+            forecast->iconName = getWeatherIcon(dayIcons(), summaryLC);
             // db uses original strings normalized to lowercase, but we prefer the unnormalized if without translation
             const QString summaryTranslated = i18nc("weather forecast", summaryLC.toUtf8().data());
             forecast->summary = (summaryTranslated != summaryLC) ? summaryTranslated : summary;
@@ -996,10 +993,6 @@ void UKMETIon::updateWeather(const QString& source)
     int i = 0;
     for (const WeatherData::ForecastInfo* forecastInfo : forecasts) {
         QString period = forecastInfo->period;
-        // same day
-        period.replace(QStringLiteral("Today"), i18nc("Short for Today", "Today"));
-        period.replace(QStringLiteral("Tonight"), i18nc("Short for Tonight", "Tonight"));
-        // upcoming days
         period.replace(QStringLiteral("Saturday"), i18nc("Short for Saturday", "Sat"));
         period.replace(QStringLiteral("Sunday"), i18nc("Short for Sunday", "Sun"));
         period.replace(QStringLiteral("Monday"), i18nc("Short for Monday", "Mon"));
