@@ -32,8 +32,8 @@ class AlternativesHelper : public QObject
     Q_PROPERTY(QQuickItem *applet READ applet CONSTANT)
 
 public:
-    AlternativesHelper(Plasma::Applet *applet, QObject *parent = 0);
-    ~AlternativesHelper();
+    explicit AlternativesHelper(Plasma::Applet *applet, QObject *parent = nullptr);
+    ~AlternativesHelper() override;
 
     QQuickItem *applet() const;
     QStringList appletProvides() const;
