@@ -24,11 +24,13 @@
 #include <QQmlEngine>
 #include <QQmlContext>
 #include <QScreen>
+#include <QQuickItem>
 #include <qopenglshaderprogram.h>
 
 #include <kwindowsystem.h>
 #include <klocalizedstring.h>
 #include <KAuthorized>
+#include <kactivities/controller.h>
 
 #include <KPackage/Package>
 
@@ -36,7 +38,7 @@
 #include <KWayland/Client/surface.h>
 
 DesktopView::DesktopView(Plasma::Corona *corona, QScreen *targetScreen)
-    : PlasmaQuick::ContainmentView(corona, 0),
+    : PlasmaQuick::ContainmentView(corona, nullptr),
       m_windowType(Desktop),
       m_shellSurface(nullptr)
 {
@@ -57,14 +59,21 @@ DesktopView::DesktopView(Plasma::Corona *corona, QScreen *targetScreen)
     QObject::connect(corona, &Plasma::Corona::kPackageChanged,
                      this, &DesktopView::coronaPackageChanged);
 
-    if (QQuickWindow::sceneGraphBackend() != QLatin1String("software")) {
+    KActivities::Controller *m_activityController = new KActivities::Controller(this);
+    
+    QObject::connect(m_activityController, &KActivities::Controller::activityAdded,
+                     this, &DesktopView::candidateContainmentsChanged);
+    QObject::connect(m_activityController, &KActivities::Controller::activityRemoved,
+                     this, &DesktopView::candidateContainmentsChanged);
+
+    if (rendererInterface()->graphicsApi() != QSGRendererInterface::Software) {
         connect(this, &DesktopView::sceneGraphInitialized, this,
             [this, corona]() {
                 // check whether the GL Context supports OpenGL
                 // Note: hasOpenGLShaderPrograms is broken, see QTBUG--39730
                 if (!QOpenGLShaderProgram::hasOpenGLShaderPrograms(openglContext())) {
                     qWarning() << "GLSL not available, Plasma won't be functional";
-                    QMetaObject::invokeMethod(corona, "showOpenGLNotCompatibleWarning", Qt::QueuedConnection);
+                    QMetaObject::invokeMethod(corona, "glInitializationFailed", Qt::QueuedConnection);
                 }
             }, Qt::DirectConnection);
     }
@@ -197,6 +206,19 @@ DesktopView::SessionType DesktopView::sessionType() const
     }
 }
 
+QVariantMap DesktopView::candidateContainmentsGraphicItems() const
+{
+    QVariantMap map;
+    if (!containment()) {
+        return map;
+    }
+
+    for (auto cont : corona()->containmentsForScreen(containment()->screen())) {
+        map[cont->activity()] = cont->property("_plasma_graphicObject");
+    }
+    return map;
+}
+
 bool DesktopView::event(QEvent *e)
 {
     if (e->type() == QEvent::PlatformSurface) {
@@ -294,7 +316,7 @@ void DesktopView::screenGeometryChanged()
 
 void DesktopView::coronaPackageChanged(const KPackage::Package &package)
 {
-    setContainment(0);
+    setContainment(nullptr);
     setSource(package.fileUrl("views", QStringLiteral("Desktop.qml")));
 }
 
